import math, sys, h5py
from pyscf import gto, scf, mcscf
from pyscf.lib import logger
from pyscf.data.nist import BOHR
from mrh.my_pyscf import mcpdft
from mrh.my_pyscf.fci import csf_solver
from mrh.my_pyscf.grad import sipdft
import numpy as np

r = 1.2
if len (sys.argv) > 1: r = float (sys.argv[1])
xyz = 'He 0 0 0; H {:.1f} 0 0'.format (r)
mol = gto.M (atom = xyz, basis='cc-pvdz', symmetry=False, charge=1, 
    verbose=logger.DEBUG,
    output='HeHp_cms2ftlda22_ccpvdz_angrad.{:.2f}.log'.format (r))
mf = scf.RHF (mol).run ()
mc = mcpdft.CASSCF (mf, 'ftLDA,VWN3', 2, 2, grids_level=9)
mc.fcisolver = csf_solver (mol, smult=1)
mc = mc.state_interaction ([0.5,0.5], 'cms')
mc.conv_tol = mc.conv_tol_sarot = 1e-12
with h5py.File ('HeHp_cms2ftlda22_ccpvdz_scan.h5', 'r') as f:
    r_list = f['r']
    mo_coeff_list = f['mo_coeff']
    ci_list = f['ci']
    print (r_list[:])
    i = np.argmin (np.abs (r_list[:]-r))
    if np.abs (r_list[i]-r) < 1e-10:
        mo0 = np.array (mo_coeff_list[i])
        ci0 = list (np.array (ci_list[i]))
mc.kernel (mo0, ci0)

mc_grad = sipdft.Gradients (mc)
de0 = mc_grad.kernel (state=0)[1,0] / BOHR
de1 = mc_grad.kernel (state=1)[1,0] / BOHR
with h5py.File ('HeHp_cms2ftlda22_ccpvdz_angrad.h5') as f:
    i = np.argmin (np.abs (f['grad_tab'][:,0]-r))
    if abs (f['grad_tab'][i,0]-r) < 1e-8:
        f['grad_tab'][i,1:] = [de0, de1]
        print (np.asarray (f['grad_tab']))


